The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Title: Diagnostic Tool by Multiple Imputation for Regression Discontinuity Designs
Version: 0.1.0
Description: Estimates local average treatment effects based on regression discontinuity designs (RDD) and multiple imputation regression discontinuity designs (MIRDD). It provides diagnostic tools for RDD by comparing results with those from MIRDD, as proposed in Takahashi (2023) <doi:10.1080/03610918.2021.1960374>.
License: GPL-3
Encoding: UTF-8
Imports: Amelia, rdrobust, stats, graphics
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-14 08:52:40 UTC; masay
Author: Masayoshi Takahashi [aut, cre]
Maintainer: Masayoshi Takahashi <mtakahashi615@g.chuo-u.ac.jp>
Repository: CRAN
Date/Publication: 2026-03-19 14:10:08 UTC

Diagnostic Tool by Multiple Imputation for Regression Discontinuity Designs

Description

Estimates local average treatment effects based on regression discontinuity designs (RDD) and multiple imputation regression discontinuity designs (MIRDD). It provides diagnostic tools for RDD by comparing results with those from MIRDD.

Usage

MIdiagRDD(
  y,
  x,
  cut,
  seed = 1,
  M1 = 100,
  M2 = 5,
  M3 = 1,
  p2s1 = 1,
  emp = 0,
  bw = "mserd",
  ker = "triangular",
  bwidth = 1,
  p1 = 1,
  conf = 95,
  upper = 1,
  covs1 = NULL,
  up = NULL,
  lo = NULL
)

Arguments

y

A numeric vector of the outcome variable.

x

A numeric vector of the assignment variable (forcing variable).

cut

A numeric value indicating the cutoff point.

seed

A seed number for reproducibility. Default is 1.

M1

Number of imputations for MIRDD. Default is 100.

M2

Number of imputations for visualization. Default is 5.

M3

Number of imputations for specific plots. Default is 1.

p2s1

Integer for Amelia's p2s argument (0, 1, or 2). Default is 1.

emp

Amelia's empriical prior. Default is 0.

bw

Bandwidth selection method for rdrobust. Default is "mserd".

ker

Kernel function for rdrobust. Default is "triangular".

bwidth

Scaling factor for bandwidth. Default is 1.

p1

Polynomial order for rdrobust. Default is 1.

conf

Confidence level (0-100). Default is 95.

upper

If 1 (default), treatment is x >= cut. If 0, treatment is x < cut.

covs1

Optional covariates for Amelia.

up

Optional upper bound for plots.

lo

Optional lower bound for plots.

Value

No return value, called for side effects (plotting and printing results).

Examples

# Example usage with dummy data
x <- runif(100, -1, 1)
y <- 0.5 * x + (x >= 0) + rnorm(100, 0, 0.1)
MIdiagRDD(y = y, x = x, cut = 0)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.